@@ -177,11 +177,19 @@ gst_registry_binary_cache_init (GstRegistry * registry, const char *location)
   cache->tmp_location = g_strconcat (location, ".tmpXXXXXX", NULL);
   cache->cache_fd = g_mkstemp (cache->tmp_location);
   if (cache->cache_fd == -1) {
+    int ret;
+    GStatBuf statbuf;
     gchar *dir;
 
     /* oops, I bet the directory doesn't exist */
     dir = g_path_get_dirname (location);
     g_mkdir_with_parents (dir, 0777);
+
+    ret = g_stat (dir, &statbuf);
+    if (ret != -1 && (statbuf.st_mode & 0700) != 0700) {
+      g_chmod (dir, 0700);
+    }
+
     g_free (dir);
 
     /* the previous g_mkstemp call overwrote the XXXXXX placeholder ... */
@@ -195,6 +203,11 @@ gst_registry_binary_cache_init (GstRegistry * registry, const char *location)
       g_slice_free (BinaryRegistryCache, cache);
       return NULL;
     }
+
+    ret = g_stat (cache->tmp_location, &statbuf);
+    if (ret != -1 && (statbuf.st_mode & 0600) != 0600) {
+      g_chmod (cache->tmp_location, 0600);
+    }
   }
 
   return cache;
@@ -206,10 +219,11 @@ gst_registry_binary_cache_write (BinaryRegistryCache * cache,
 {
   long written;
   if (offset != cache->currentoffset) {
-    if (lseek (cache->cache_fd, offset, SEEK_SET) != 0) {
-      GST_ERROR ("Seeking to new offset failed");
-      return FALSE;
+    if (lseek (cache->cache_fd, offset, SEEK_SET) < 0) {
+      GST_ERROR ("Seeking to new offset failed: %s", g_strerror (errno));
+      return -1;
     }
+    GST_LOG ("Seeked from offset %lu to %lu", offset, cache->currentoffset);
     cache->currentoffset = offset;
   }
 
@@ -232,12 +246,13 @@ gst_registry_binary_cache_finish (BinaryRegistryCache * cache, gboolean success)
   if (close (cache->cache_fd) < 0)
     goto close_failed;
 
-  if (success) {
-    /* Only do the rename if we wrote the entire file successfully */
-    if (g_rename (cache->tmp_location, cache->location) < 0) {
-      GST_ERROR ("g_rename() failed: %s", g_strerror (errno));
-      goto rename_failed;
-    }
+  if (!success)
+    goto fail_after_close;
+
+  /* Only do the rename if we wrote the entire file successfully */
+  if (g_rename (cache->tmp_location, cache->location) < 0) {
+    GST_ERROR ("g_rename() failed: %s", g_strerror (errno));
+    goto rename_failed;
   }
 
   g_free (cache->tmp_location);
@@ -336,11 +351,12 @@ gst_registry_binary_initialize_magic (GstBinaryRegistryMagic * m)
  * @location: a filename
  *
  * Write the @registry to a cache to file at given @location.
- * 
+ *
  * Returns: %TRUE on success.
  */
 gboolean
-gst_registry_binary_write_cache (GstRegistry * registry, const char *location)
+priv_gst_registry_binary_write_cache (GstRegistry * registry, GList * plugins,
+    const char *location)
 {
   GList *walk;
   GstBinaryRegistryMagic magic;
@@ -356,14 +372,14 @@ gst_registry_binary_write_cache (GstRegistry * registry, const char *location)
     goto fail;
 
   /* iterate trough the list of plugins and fit them into binary structures */
-  for (walk = registry->plugins; walk; walk = g_list_next (walk)) {
+  for (walk = plugins; walk != NULL; walk = walk->next) {
     GstPlugin *plugin = GST_PLUGIN (walk->data);
 
     if (!plugin->filename)
       continue;
 
-    if (plugin->flags & GST_PLUGIN_FLAG_CACHED) {
-      struct stat statbuf;
+    if (GST_OBJECT_FLAG_IS_SET (plugin, GST_PLUGIN_FLAG_CACHED)) {
+      GStatBuf statbuf;
 
       if (g_stat (plugin->filename, &statbuf) < 0 ||
           plugin->file_mtime != statbuf.st_mtime ||
@@ -377,6 +393,9 @@ gst_registry_binary_write_cache (GstRegistry * registry, const char *location)
     }
   }
 
+  _priv_gst_registry_chunks_save_global_header (&to_write, registry,
+      priv_gst_plugin_loading_get_whitelist_hash ());
+
   GST_INFO ("Writing binary registry cache");
 
   cache = gst_registry_binary_cache_init (registry, location);
@@ -487,7 +506,8 @@ fail:
  * Returns: %TRUE on success.
  */
 gboolean
-gst_registry_binary_read_cache (GstRegistry * registry, const char *location)
+priv_gst_registry_binary_read_cache (GstRegistry * registry,
+    const char *location)
 {
   GMappedFile *mapped = NULL;
   gchar *contents = NULL;
@@ -495,6 +515,7 @@ gst_registry_binary_read_cache (GstRegistry * registry, const char *location)
   gsize size;
   GError *err = NULL;
   gboolean res = FALSE;
+  guint32 filter_env_hash = 0;
   gint check_magic_result;
 #ifndef GST_DISABLE_GST_DEBUG
   GTimer *timer = NULL;
@@ -504,7 +525,6 @@ gst_registry_binary_read_cache (GstRegistry * registry, const char *location)
   /* make sure these types exist */
   GST_TYPE_ELEMENT_FACTORY;
   GST_TYPE_TYPE_FIND_FACTORY;
-  GST_TYPE_INDEX_FACTORY;
 
 #ifndef GST_DISABLE_GST_DEBUG
   timer = g_timer_new ();
@@ -554,6 +574,18 @@ gst_registry_binary_read_cache (GstRegistry * registry, const char *location)
     goto Error;
   }
 
+  if (!_priv_gst_registry_chunks_load_global_header (registry, &in,
+          contents + size, &filter_env_hash)) {
+    GST_ERROR ("Couldn't read global header chunk");
+    goto Error;
+  }
+
+  if (filter_env_hash != priv_gst_plugin_loading_get_whitelist_hash ()) {
+    GST_INFO_OBJECT (registry, "Plugin loading filter environment changed, "
+        "ignoring plugin cache to force update with new filter environment");
+    goto done;
+  }
+
   /* check if there are plugins in the file */
   if (G_UNLIKELY (!(((gsize) in + sizeof (GstRegistryChunkPluginElement)) <
               (gsize) contents + size))) {
@@ -575,6 +607,8 @@ gst_registry_binary_read_cache (GstRegistry * registry, const char *location)
     }
   }
 
+done:
+
 #ifndef GST_DISABLE_GST_DEBUG
   g_timer_stop (timer);
   seconds = g_timer_elapsed (timer, NULL);
@@ -586,44 +620,13 @@ gst_registry_binary_read_cache (GstRegistry * registry, const char *location)
   /* TODO: once we re-use the pointers to registry contents, return here */
 
 Error:
-  if (err)
-    g_error_free (err);
-
 #ifndef GST_DISABLE_GST_DEBUG
   g_timer_destroy (timer);
 #endif
   if (mapped) {
-#if GLIB_CHECK_VERSION(2,22,0)
     g_mapped_file_unref (mapped);
-#else
-    g_mapped_file_free (mapped);
-#endif
   } else {
     g_free (contents);
   }
   return res;
 }
-
-#ifndef GST_REMOVE_DEPRECATED
-#ifdef GST_DISABLE_DEPRECATED
-gboolean
-gst_registry_xml_read_cache (GstRegistry * registry, const char *location);
-#endif
-/* FIXME 0.11: these symbols are here for backwards compatibility and should
- * be removed or made private */
-gboolean
-gst_registry_xml_read_cache (GstRegistry * registry, const char *location)
-{
-  return FALSE;
-}
-
-#ifdef GST_DISABLE_DEPRECATED
-gboolean
-gst_registry_xml_write_cache (GstRegistry * registry, const char *location);
-#endif
-gboolean
-gst_registry_xml_write_cache (GstRegistry * registry, const char *location)
-{
-  return FALSE;
-}
-#endif /* GST_REMOVE_DEPRECATED */
